@@ -277,7 +277,7 @@ Write your filter like this:
       ["Save %_As..." write-file]
       ["Save So%_me Buffers" save-some-buffers]
       "-----"
-      ,@(if (eq system-type 'windows-nt)
+      ,@(if (valid-specifier-tag-p 'msprinter)
 	  '(["Page Set%_up..." generic-page-setup]))
       ["%_Print" generic-print-buffer
        :active (or (valid-specifier-tag-p 'msprinter)
@@ -286,7 +286,7 @@ Write your filter like this:
        :suffix (if (region-active-p) "Selection..."
 		 (if put-buffer-names-in-file-menu (concat (buffer-name) "...")
 		   "..."))]
-      ,@(unless (eq system-type 'windows-nt)
+      ,@(unless (valid-specifier-tag-p 'msprinter)
 	  '(["Prett%_y-Print" ps-print-buffer-with-faces
 	     :active (fboundp 'ps-print-buffer-with-faces)
 	     :suffix (if put-buffer-names-in-file-menu (buffer-name) "")]))
