@@ -24,29 +24,33 @@
 
 ;;; Commentary:
 
-;; For Hebrew, the character sets ISO8859-8 is supported.
+;;  ISO 8859-8 (Hebrew) support.
 
 ;;; Code:
 
+; (make-charset 'hebrew-iso8859-8 
+; 	      "Right-Hand Part of Latin/Hebrew Alphabet (ISO/IEC 8859-8): ISO-IR-138"
+; 	      '(dimension
+; 		1
+; 		registry "ISO8859-8"
+; 		chars 96
+; 		columns 1
+; 		direction r2l
+; 		final ?H
+; 		graphic 1
+; 		short-name "RHP of ISO8859/8"
+; 		long-name "RHP of Hebrew (ISO 8859-8): ISO-IR-138"
+; 		))
+
 ;; Syntax of Hebrew characters
 (loop for c from 96 to 122
       do (modify-syntax-entry (make-char 'hebrew-iso8859-8 c) "w"))
 (modify-syntax-entry (make-char 'hebrew-iso8859-8 32) "w") ; no-break space
 
 
-;; (make-coding-system
-;;  'hebrew-iso-8bit 2 ?8
-;;  "ISO 2022 based 8-bit encoding for Hebrew (MIME:ISO-8859-8)"
-;;  '(ascii hebrew-iso8859-8 nil nil
-;;    nil ascii-eol ascii-cntl nil nil nil nil nil t)
-;;  '((safe-charsets ascii hebrew-iso8859-8)
-;;    (mime-charset . iso-8859-8)))
-
-;; (define-coding-system-alias 'iso-8859-8 'hebrew-iso-8bit)
-
 (make-coding-system
  'iso-8859-8 'iso2022
- "MIME ISO-8859-8"
+ "ISO-8859-8 (Hebrew)"
  '(charset-g0 ascii
    charset-g1 hebrew-iso8859-8
    charset-g2 t
@@ -57,7 +61,7 @@
 
 (make-coding-system
  'ctext-hebrew 'iso2022
- "Coding-system of Hebrew."
+ "ISO-8859-8-E (Hebrew, explicit directional coding)"
  '(charset-g0 ascii
    charset-g1 hebrew-iso8859-8
    charset-g2 t
@@ -65,12 +69,6 @@
    mnemonic "CText/Hbrw"
    ))
 
-(defun setup-hebrew-environment ()
-  "Setup multilingual environment (MULE) for Hebrew.
-But, please note that right-to-left writing is not yet supported."
-  (interactive)
-  (set-language-environment "Hebrew"))
-
 (set-language-info-alist
  "Hebrew" '((charset hebrew-iso8859-8)
 	    (coding-system iso-8859-8)
