@@ -1635,11 +1635,20 @@ static const struct lrecord_description weak_list_description[] = {
   { XD_END }
 };
 
+#ifdef USE_KKCC
+DEFINE_LRECORD_IMPLEMENTATION ("weak-list", weak_list,
+			       1, /*dumpable-flag*/
+			       mark_weak_list, print_weak_list,
+			       0, weak_list_equal, weak_list_hash,
+			       weak_list_description,
+			       struct weak_list);
+#else /* not USE_KKCC */
 DEFINE_LRECORD_IMPLEMENTATION ("weak-list", weak_list,
 			       mark_weak_list, print_weak_list,
 			       0, weak_list_equal, weak_list_hash,
 			       weak_list_description,
 			       struct weak_list);
+#endif /* not USE_KKCC */
 /*
    -- we do not mark the list elements (either the elements themselves
       or the cons cells that hold them) in the normal marking phase.
@@ -2096,11 +2105,20 @@ static const struct lrecord_description weak_box_description[] = {
   { XD_END}
 };
 
+#ifdef USE_KKCC
+DEFINE_LRECORD_IMPLEMENTATION ("weak_box", weak_box,
+			       0, /*dumpable-flag*/
+			       mark_weak_box, print_weak_box,
+			       0, weak_box_equal, weak_box_hash,
+			       weak_box_description,
+			       struct weak_box);
+#else /* not USE_KKCC */
 DEFINE_LRECORD_IMPLEMENTATION ("weak_box", weak_box,
 			       mark_weak_box, print_weak_box,
 			       0, weak_box_equal, weak_box_hash,
 			       weak_box_description,
 			       struct weak_box);
+#endif /* not USE_KKCC */
 
 DEFUN ("make-weak-box", Fmake_weak_box, 1, 1, 0, /*
 Return a new weak box from value CONTENTS.
@@ -2275,11 +2293,20 @@ static const struct lrecord_description ephemeron_description[] = {
   { XD_END }
 };
 
+#ifdef USE_KKCC
+DEFINE_LRECORD_IMPLEMENTATION ("ephemeron", ephemeron,
+			       0, /*dumpable-flag*/
+			       mark_ephemeron, print_ephemeron,
+			       0, ephemeron_equal, ephemeron_hash,
+			       ephemeron_description,
+			       struct ephemeron);
+#else /* not USE_KKCC */
 DEFINE_LRECORD_IMPLEMENTATION ("ephemeron", ephemeron,
 			       mark_ephemeron, print_ephemeron,
 			       0, ephemeron_equal, ephemeron_hash,
 			       ephemeron_description,
 			       struct ephemeron);
+#endif /* not USE_KKCC */
 
 DEFUN ("make-ephemeron", Fmake_ephemeron, 2, 3, 0, /*
 Return a new ephemeron with key KEY, value CONTENTS, and finalizer FINALIZER.
