@@ -28,28 +28,30 @@ Boston, MA 02111-1307, USA.  */
 #include <config.h>
 #include "lisp.h"
 
-#include "console-gtk.h"
-
 #include "blocktype.h"
 #include "buffer.h"
 #include "commands.h"
 #include "console.h"
-#include "console-tty.h"
+#include "device-impl.h"
+#include "elhash.h"
 #include "events.h"
-#include "frame.h"
-#include "objects-gtk.h"
+#include "file-coding.h"
+#include "frame-impl.h"
+#include "lstream.h"
 #include "process.h"
 #include "redisplay.h"
-#include "elhash.h"
+#include "window.h"
+
+#include "console-tty.h"
+
+#include "console-gtk-impl.h"
+#include "objects-gtk.h"
 
 #include "gtk-xemacs.h"
 
 #include "systime.h"
 #include "sysproc.h" /* for MAXDESC */
 
-#include "lstream.h"
-#include "file-coding.h"
-
 #include <gdk/gdkkeysyms.h>
 
 #ifdef HAVE_DRAGNDROP
@@ -148,10 +150,12 @@ change_frame_visibility (struct frame *f, int is_visible)
   if (!FRAME_VISIBLE_P (f) && is_visible)
     {
       FRAME_VISIBLE_P (f) = is_visible;
-      /* This improves the double flicker when uniconifying a frame
+      /* [[ This improves the double flicker when uniconifying a frame
 	 some.  A lot of it is not showing a buffer which has changed
 	 while the frame was iconified.  To fix it further requires
-	 the good 'ol double redisplay structure. */
+	 the good 'ol double redisplay structure. ]] -- comment is
+	 invalid, obviously predates 19.12, when the double redisplay
+	 structure (i.e. current + desired) was put back  in. --ben */
       MARK_FRAME_WINDOWS_STRUCTURE_CHANGED (f);
       va_run_hook_with_args (Qmap_frame_hook, 1, frame);
     }
@@ -192,9 +196,6 @@ handle_map_event (struct frame *f, GdkEvent *event)
 static void
 handle_client_message (struct frame *f, GdkEvent *event)
 {
-  Lisp_Object frame = wrap_frame (f);
-
-
   /* The event-Xt code used to handle WM_DELETE_WINDOW here, but we
      handle that directly in frame-gtk.c */
 	 
@@ -210,8 +211,9 @@ emacs_gtk_format_magic_event (Lisp_Event *emacs_event, Lisp_Object pstream)
 {
   Lisp_Object console = CDFW_CONSOLE (EVENT_CHANNEL (emacs_event));
   if (CONSOLE_GTK_P (XCONSOLE (console)))
-    write_c_string (gtk_event_name (emacs_event->event.magic.underlying_gdk_event.type),
-		    pstream);
+    write_c_string
+      (pstream,
+       gtk_event_name (emacs_event->event.magic.underlying_gdk_event.type));
 }
 
 static int
@@ -445,7 +447,7 @@ gtk_to_emacs_keysym (struct device *d, GdkEventKey *event, int simple_p)
   if (event->length != 1)
     {
       /* Generate multiple emacs events */
-      Emchar ch;
+      Ichar ch;
       Lisp_Object instream, fb_instream;
       Lstream *istr;
       struct gcpro gcpro1, gcpro2;
@@ -462,7 +464,7 @@ gtk_to_emacs_keysym (struct device *d, GdkEventKey *event, int simple_p)
       istr = XLSTREAM (instream);
 
       GCPRO2 (instream, fb_instream);
-      while ((ch = Lstream_get_emchar (istr)) != EOF)
+      while ((ch = Lstream_get_ichar (istr)) != EOF)
 	{
 	  Lisp_Object emacs_event = Fmake_event (Qnil, Qnil);
 	  struct Lisp_Event *ev = XEVENT (emacs_event);
@@ -496,10 +498,11 @@ gtk_to_emacs_keysym (struct device *d, GdkEventKey *event, int simple_p)
 
 static int timeout_id_tick;
 
-struct GTK_timeout {
-    int id;
-    guint timeout_id;
-    struct GTK_timeout *next;
+struct GTK_timeout
+{
+  int id;
+  guint timeout_id;
+  struct GTK_timeout *next;
 } *pending_timeouts, *completed_timeouts;
 
 struct GTK_timeout_blocktype
@@ -526,7 +529,7 @@ gtk_timeout_callback (gpointer closure)
   /* Add this one to the list of completed timeouts */
   timeout->next = completed_timeouts;
   completed_timeouts = timeout;
-  return(FALSE);
+  return FALSE;
 }
 
 static int
@@ -685,15 +688,11 @@ mark_what_as_being_ready (struct what_is_ready_closure *closure)
 	}
       filedesc_with_input[closure->fd] = closure->what;
       if (PROCESSP (closure->what))
-	{
-	  /* Don't increment this if the current process is already marked
-	   *  as having input. */
-	  process_events_occurred++;
-	}
+	/* Don't increment this if the current process is already marked
+	 *  as having input. */
+	process_events_occurred++;
       else
-	{
-	  tty_events_occurred++;
-	}
+	tty_events_occurred++;
     }
 }
 
@@ -778,39 +777,62 @@ unselect_filedesc (int fd)
 }
 
 static void
-emacs_gtk_select_process (struct Lisp_Process *p)
+emacs_gtk_select_process (Lisp_Process *process, int doin, int doerr)
 {
-  Lisp_Object process;
-  int infd = event_stream_unixoid_select_process (p);
+  Lisp_Object proc;
+  int infd, errfd;
 
-  process = wrap_process (p);
-  select_filedesc (infd, process);
+  event_stream_unixoid_select_process (process, doin, doerr, &infd, &errfd);
+
+  proc = wrap_process (process);
+  if (doin)
+    select_filedesc (infd, proc);
+  if (doerr)
+    select_filedesc (errfd, proc);
 }
 
 static void
-emacs_gtk_unselect_process (struct Lisp_Process *p)
+emacs_gtk_unselect_process (Lisp_Process *process, int doin, int doerr)
 {
-  int infd = event_stream_unixoid_unselect_process (p);
+  int infd, errfd;
 
-  unselect_filedesc (infd);
+  event_stream_unixoid_unselect_process (process, doin, doerr, &infd, &errfd);
+
+  if (doin)
+    unselect_filedesc (infd);
+  if (doerr)
+    unselect_filedesc (errfd);
 }
 
-static USID
-emacs_gtk_create_stream_pair (void* inhandle, void* outhandle,
-			      Lisp_Object* instream, Lisp_Object* outstream, int flags)
+static void
+emacs_gtk_create_io_streams (void *inhandle, void *outhandle,
+			     void *errhandle, Lisp_Object *instream,
+			     Lisp_Object *outstream,
+			     Lisp_Object *errstream,
+			     USID *in_usid,
+			     USID *err_usid,
+			     int flags)
 {
-    USID u = event_stream_unixoid_create_stream_pair
-	(inhandle, outhandle, instream, outstream, flags);
-    if (u != USID_ERROR)
-	u = USID_DONTHASH;
-    return u;
+  event_stream_unixoid_create_io_streams
+    (inhandle, outhandle, errhandle, instream, outstream,
+     errstream, in_usid, err_usid, flags);
+  if (*in_usid != USID_ERROR)
+    *in_usid = USID_DONTHASH;
+  if (*err_usid != USID_ERROR)
+    *err_usid = USID_DONTHASH;
 }
 
-static USID
-emacs_gtk_delete_stream_pair (Lisp_Object instream, Lisp_Object outstream)
+static void
+emacs_gtk_delete_io_streams (Lisp_Object instream,
+			     Lisp_Object outstream,
+			     Lisp_Object errstream,
+			     USID *in_usid,
+			     USID *err_usid)
 {
-  event_stream_unixoid_delete_stream_pair (instream, outstream);
-  return USID_DONTHASH;
+  event_stream_unixoid_delete_io_streams
+    (instream, outstream, errstream, in_usid, err_usid);
+  *in_usid = USID_DONTHASH;
+  *err_usid = USID_DONTHASH;
 }
 
 /* This is called from GC when a process object is about to be freed.
@@ -988,7 +1010,7 @@ dragndrop_data_received (GtkWidget          *widget,
       /* Random filename */
       char *hurl = dnd_url_hexify_string (data->data, "file:");
 
-      l_dndlist = list1 (make_string ((Intbyte *)hurl, strlen (hurl)));
+      l_dndlist = list1 (make_string ((Ibyte *)hurl, strlen (hurl)));
       l_type = Qdragdrop_URL;
 
       xfree (hurl);
@@ -1186,9 +1208,11 @@ gtk_event_to_emacs_event (struct frame *frame, GdkEvent *gdk_event, struct Lisp_
   struct gtk_device *gd = NULL;
   gboolean accept_any_window = FALSE;
 
+  /* #### Under what circumstances can this happen???? Hunt out the code that
+     sets frame to 0 and fix it instead. */
   if (!frame)
     {
-      frame = XFRAME (Fselected_frame (Vdefault_gtk_device));
+      frame = XFRAME (Fselected_frame (get_default_device (Qgtk)));
       accept_any_window = TRUE;
     }
 
@@ -1533,7 +1557,7 @@ check_for_tty_quit_char (struct device *d)
   SELECT_TYPE temp_mask;
   int infd = DEVICE_INFD (d);
   struct console *con = XCONSOLE (DEVICE_CONSOLE (d));
-  Emchar quit_char = CONSOLE_QUIT_CHAR (con);
+  Ichar quit_char = CONSOLE_QUIT_CHAR (con);
 
   FD_ZERO (&temp_mask);
   FD_SET (infd, &temp_mask);
@@ -1541,7 +1565,7 @@ check_for_tty_quit_char (struct device *d)
   while (1)
     {
       Lisp_Object event;
-      Emchar the_char;
+      Ichar the_char;
 
       if (!poll_fds_for_input (temp_mask))
 	return;
@@ -1759,8 +1783,8 @@ void reinit_vars_of_event_gtk (void)
   gtk_event_stream->select_process_cb 	= emacs_gtk_select_process;
   gtk_event_stream->unselect_process_cb = emacs_gtk_unselect_process;
   gtk_event_stream->quit_p_cb		= emacs_gtk_quit_p;
-  gtk_event_stream->create_stream_pair_cb= emacs_gtk_create_stream_pair;
-  gtk_event_stream->delete_stream_pair_cb= emacs_gtk_delete_stream_pair;
+  gtk_event_stream->create_io_streams_cb= emacs_gtk_create_io_streams;
+  gtk_event_stream->delete_io_streams_cb= emacs_gtk_delete_io_streams;
   gtk_event_stream->force_event_pending	 = emacs_gtk_force_event_pending;
 
   the_GTK_timeout_blocktype = Blocktype_new (struct GTK_timeout_blocktype);
