@@ -276,11 +276,20 @@ static const struct lrecord_description face_description[] = {
   { XD_END }
 };
 
+#ifdef USE_KKCC
+DEFINE_LRECORD_IMPLEMENTATION_WITH_PROPS ("face", face,
+					  1, /*dumpable-flag*/
+					  mark_face, print_face, 0, face_equal,
+					  face_hash, face_description, face_getprop,
+					  face_putprop, face_remprop,
+					  face_plist, Lisp_Face);
+#else /* not USE_KKCC */
 DEFINE_LRECORD_IMPLEMENTATION_WITH_PROPS ("face", face,
 					  mark_face, print_face, 0, face_equal,
 					  face_hash, face_description, face_getprop,
 					  face_putprop, face_remprop,
 					  face_plist, Lisp_Face);
+#endif /* not USE_KKCC */
 
 /************************************************************************/
 /*                             face read syntax                         */
