@@ -1,6 +1,6 @@
 /* Functions for the X window system.
    Copyright (C) 1989, 1992-5, 1997 Free Software Foundation, Inc.
-   Copyright (C) 1995, 1996, 2001 Ben Wing.
+   Copyright (C) 1995, 1996, 2001, 2002 Ben Wing.
 
 This file is part of XEmacs.
 
@@ -29,17 +29,17 @@ Boston, MA 02111-1307, USA.  */
 #include "lisp.h"
 
 #include "buffer.h"
-#include "device.h"
+#include "device-impl.h"
 #include "events.h"
 #include "extents.h"
 #include "faces.h"
-#include "frame.h"
-#include "window.h"
+#include "frame-impl.h"
 #include "gutter.h"
+#include "window.h"
 
-#include "console-x.h"
+#include "console-x-impl.h"
 #include "glyphs-x.h"
-#include "objects-x.h"
+#include "objects-x-impl.h"
 #include "scrollbar-x.h"
 
 #include "xintrinsicp.h"	/* CoreP.h needs this */
@@ -453,14 +453,6 @@ init_x_prop_symbols (void)
   def (Qunsplittable, XtNunsplittable);
 #endif
   defi(Qinternal_border_width, XtNinternalBorderWidth);
-#ifdef HAVE_TOOLBARS
-  def (Qtop_toolbar_shadow_color, XtNtopToolBarShadowColor);
-  def (Qbottom_toolbar_shadow_color, XtNbottomToolBarShadowColor);
-  def (Qbackground_toolbar_color, XtNbackgroundToolBarColor);
-  def (Qtop_toolbar_shadow_pixmap, XtNtopToolBarShadowPixmap);
-  def (Qbottom_toolbar_shadow_pixmap, XtNbottomToolBarShadowPixmap);
-  defi(Qtoolbar_shadow_thickness, XtNtoolBarShadowThickness);
-#endif
   def (Qscrollbar_placement, XtNscrollBarPlacement);
   defi(Qinter_line_space, XtNinterline);
   /* font, foreground */
@@ -494,7 +486,7 @@ init_x_prop_symbols (void)
 static Lisp_Object
 color_to_string (Widget w, unsigned long pixel)
 {
-  Intbyte buf[255];
+  Ibyte buf[255];
 
   XColor color;
   color.pixel = pixel;
@@ -567,16 +559,6 @@ x_frame_property (struct frame *f, Lisp_Object property)
     return make_int (w->emacs_frame.internal_border_width);
   if (EQ (Qborder_color, property))
     return color_to_string (gw, w->core.border_pixel);
-#ifdef HAVE_TOOLBARS
-  if (EQ (Qtop_toolbar_shadow_color, property))
-    return color_to_string (gw, w->emacs_frame.top_toolbar_shadow_pixel);
-  if (EQ (Qbottom_toolbar_shadow_color, property))
-    return color_to_string (gw, w->emacs_frame.bottom_toolbar_shadow_pixel);
-  if (EQ (Qbackground_toolbar_color, property))
-    return color_to_string (gw, w->emacs_frame.background_toolbar_pixel);
-  if (EQ (Qtoolbar_shadow_thickness, property))
-    return make_int (w->emacs_frame.toolbar_shadow_thickness);
-#endif /* HAVE_TOOLBARS */
   if (EQ (Qinter_line_space, property))
     return make_int (w->emacs_frame.interline);
   if (EQ (Qwindow_id, property))
@@ -593,12 +575,6 @@ x_internal_frame_property_p (struct frame *f, Lisp_Object property)
     || EQ (property, Qborder_width)
     || EQ (property, Qinternal_border_width)
     || EQ (property, Qborder_color)
-#ifdef HAVE_TOOLBARS
-    || EQ (property, Qtop_toolbar_shadow_color)
-    || EQ (property, Qbottom_toolbar_shadow_color)
-    || EQ (property, Qbackground_toolbar_color)
-    || EQ (property, Qtoolbar_shadow_thickness)
-#endif /* HAVE_TOOLBARS */
     || EQ (property, Qinter_line_space)
     || EQ (property, Qwindow_id)
     || STRINGP (property);
@@ -616,21 +592,6 @@ x_frame_properties (struct frame *f)
   props = cons3 (Qwindow_id, Fx_window_id (wrap_frame (f)), props);
   props = cons3 (Qinter_line_space, make_int (w->emacs_frame.interline), props);
 
-#ifdef HAVE_TOOLBARS
-  props = cons3 (Qtoolbar_shadow_thickness,
-		 make_int (w->emacs_frame.toolbar_shadow_thickness),
-		 props);
-  props = cons3 (Qbackground_toolbar_color,
-		 color_to_string (gw, w->emacs_frame.background_toolbar_pixel),
-		 props);
-  props = cons3 (Qbottom_toolbar_shadow_color,
-		 color_to_string (gw, w->emacs_frame.bottom_toolbar_shadow_pixel),
-		 props);
-  props = cons3 (Qtop_toolbar_shadow_color,
-		 color_to_string (gw, w->emacs_frame.top_toolbar_shadow_pixel),
-		 props);
-#endif /* HAVE_TOOLBARS */
-
   props = cons3 (Qborder_color,
 		 color_to_string (gw, w->core.border_pixel), props);
   props = cons3 (Qinternal_border_width,
@@ -653,7 +614,7 @@ x_frame_properties (struct frame *f)
    individual properties. */
 
 static void
-x_set_frame_text_value (struct frame *f, Intbyte *value,
+x_set_frame_text_value (struct frame *f, Ibyte *value,
 			String Xt_resource_name,
 			String Xt_resource_encoding_name)
 {
@@ -662,10 +623,10 @@ x_set_frame_text_value (struct frame *f, Intbyte *value,
   String old_XtValue = NULL;
 
 #ifdef MULE
-  Intbyte *ptr;
+  Ibyte *ptr;
   /* Optimize for common ASCII case */
   for (ptr = value; *ptr; ptr++)
-    if (!BYTE_ASCII_P (*ptr))
+    if (!byte_ascii_p (*ptr))
       {
         const char * tmp;
         encoding = DEVICE_XATOM_COMPOUND_TEXT (XDEVICE (FRAME_DEVICE (f)));
@@ -687,13 +648,13 @@ x_set_frame_text_value (struct frame *f, Intbyte *value,
 }
 
 static void
-x_set_title_from_intbyte (struct frame *f, Intbyte *name)
+x_set_title_from_ibyte (struct frame *f, Ibyte *name)
 {
   x_set_frame_text_value (f, name, XtNtitle, XtNtitleEncoding);
 }
 
 static void
-x_set_icon_name_from_intbyte (struct frame *f, Intbyte *name)
+x_set_icon_name_from_ibyte (struct frame *f, Ibyte *name)
 {
   x_set_frame_text_value (f, name, XtNiconName, XtNiconNameEncoding);
 }
@@ -1266,7 +1227,7 @@ x_cde_transfer_callback (Widget widget, XtPointer clientData,
 	  filePath = transferInfo->dropData->data.files[ii];
 	  hurl = dnd_url_hexify_string ((char *)filePath, "file:");
           /* #### Mule-izing required */
-	  l_data = Fcons (make_string ((Intbyte* )hurl,
+	  l_data = Fcons (make_string ((Ibyte* )hurl,
 				       strlen (hurl)),
 			  l_data);
 	  xfree (hurl);
@@ -1288,11 +1249,11 @@ x_cde_transfer_callback (Widget widget, XtPointer clientData,
 	  /* let us forget this name thing for now... */
  	  /* filePath = transferInfo->dropData->data.buffers[ii].name;
 	     path = (filePath == NULL) ? Qnil
-	     : make_string ((Intbyte *)filePath, strlen (filePath)); */
+	     : make_string ((Ibyte *)filePath, strlen (filePath)); */
 	  /* what, if the data is no text, and how can I tell it? */
-	  l_data = Fcons ( list3 ( list1 ( make_string ((Intbyte *)"text/plain", 10) ),
-				   make_string ((Intbyte *)"8bit", 4),
-				   make_string ((Intbyte *)transferInfo->dropData->data.buffers[ii].bp,
+	  l_data = Fcons ( list3 ( list1 ( make_string ((Ibyte *)"text/plain", 10) ),
+				   make_string ((Ibyte *)"8bit", 4),
+				   make_string ((Ibyte *)transferInfo->dropData->data.buffers[ii].bp,
 						transferInfo->dropData->data.buffers[ii].size) ),
 			   l_data );
  	}
@@ -2289,7 +2250,7 @@ a string.
 */
        (frame))
 {
-  Intbyte str[255];
+  Ibyte str[255];
   struct frame *f = decode_x_frame (frame);
 
   qxesprintf (str, "%lu", XtWindow (FRAME_X_TEXT_WIDGET (f)));
@@ -2821,8 +2782,8 @@ console_type_create_frame_x (void)
   CONSOLE_HAS_METHOD (x, internal_frame_property_p);
   CONSOLE_HAS_METHOD (x, frame_properties);
   CONSOLE_HAS_METHOD (x, set_frame_properties);
-  CONSOLE_HAS_METHOD (x, set_title_from_intbyte);
-  CONSOLE_HAS_METHOD (x, set_icon_name_from_intbyte);
+  CONSOLE_HAS_METHOD (x, set_title_from_ibyte);
+  CONSOLE_HAS_METHOD (x, set_icon_name_from_ibyte);
   CONSOLE_HAS_METHOD (x, frame_visible_p);
   CONSOLE_HAS_METHOD (x, frame_totally_visible_p);
   CONSOLE_HAS_METHOD (x, frame_iconified_p);
