@@ -31,11 +31,11 @@ Boston, MA 02111-1307, USA.  */
 #include <config.h>
 #include "lisp.h"
 
-#include "device.h"
+#include "device-impl.h"
 #include "elhash.h"
 #include "faces.h"
 #include "file-coding.h"
-#include "frame.h"
+#include "frame-impl.h"
 #include "gui.h"
 #include "imgproc.h"
 #include "insdel.h"
@@ -45,9 +45,9 @@ Boston, MA 02111-1307, USA.  */
 #include "sysfile.h"
 #include "window.h"
 
-#include "console-msw.h"
+#include "console-msw-impl.h"
 #include "glyphs-msw.h"
-#include "objects-msw.h"
+#include "objects-msw-impl.h"
 
 #define WIDGET_GLYPH_SLOT 0
 
@@ -304,11 +304,11 @@ mswindows_locate_pixmap_file (Lisp_Object name)
 
   /* Check non-absolute pathnames with a directory component relative to
      the search path; that's the way Xt does it. */
-  if (IS_DIRECTORY_SEP(XSTRING_BYTE (name, 0)) ||
-      (XSTRING_BYTE (name, 0) == '.' &&
-       (IS_DIRECTORY_SEP(XSTRING_BYTE (name, 1)) ||
-	(XSTRING_BYTE (name, 1) == '.' &&
-	 (IS_DIRECTORY_SEP(XSTRING_BYTE (name, 2)))))))
+  if (IS_DIRECTORY_SEP(string_byte (name, 0)) ||
+      (string_byte (name, 0) == '.' &&
+       (IS_DIRECTORY_SEP(string_byte (name, 1)) ||
+	(string_byte (name, 1) == '.' &&
+	 (IS_DIRECTORY_SEP(string_byte (name, 2)))))))
     {
       if (!NILP (Ffile_readable_p (name)))
 	return Fexpand_file_name (name, Qnil);
@@ -720,7 +720,7 @@ mswindows_resize_dibitmap_instance (Lisp_Image_Instance *ii,
 
 struct color_symbol
 {
-  Intbyte *	name;
+  Ibyte *	name;
   COLORREF	color;
 };
 
@@ -779,10 +779,10 @@ extract_xpm_color_names (Lisp_Object device,
 
       /* mustn't lose this when we return */
       colortbl[j].name = qxestrdup (XSTRING_DATA (XCAR (cons)));
-      free_cons (XCONS (cons));
+      free_cons (cons);
       cons = results;
       results = XCDR (results);
-      free_cons (XCONS (cons));
+      free_cons (cons);
     }
   return colortbl;
 }
@@ -899,7 +899,7 @@ static int xpm_to_eimage (Lisp_Object image, const Extbyte *buffer,
       if (xpmimage.colorTable[i].c_color)
 	{
 	  colortbl[i]=
-	    mswindows_string_to_color ((Intbyte *)
+	    mswindows_string_to_color ((Ibyte *)
 				       xpmimage.colorTable[i].c_color);
 	  goto label_found_color;
 	}
@@ -1094,7 +1094,7 @@ mswindows_resource_possible_dest_types (void)
 
 typedef struct
 {
-  CIntbyte *name;
+  CIbyte *name;
   int	resource_id;
 } resource_t;
 
@@ -1175,7 +1175,7 @@ resource_name_to_resource (Lisp_Object name, int type)
 
   do
     {
-      if (!qxestrcasecmp_i18n ((Intbyte *) res->name, XSTRING_DATA (name)))
+      if (!qxestrcasecmp_i18n ((Ibyte *) res->name, XSTRING_DATA (name)))
 	return res->resource_id;
     }
   while ((++res)->name);
@@ -1637,7 +1637,7 @@ mswindows_xface_instantiate (Lisp_Object image_instance,
   Lisp_Object data = find_keyword_in_vector (instantiator, Q_data);
   int i, stattis;
   UChar_Binary *p, *bits, *bp;
-  const CIntbyte * volatile emsg = 0;
+  const CIbyte * volatile emsg = 0;
   const UChar_Binary * volatile dstring;
 
   assert (!NILP (data));
@@ -1674,11 +1674,11 @@ mswindows_xface_instantiate (Lisp_Object image_instance,
   if (emsg)
     signal_image_error_2 (emsg, data, Qimage);
 
-  bp = bits = (UChar_Binary *) alloca (PIXELS / 8);
+  bp = bits = (UChar_Binary *) ALLOCA (PIXELS / 8);
 
   /* the compface library exports char F[], which uses a single byte per
      pixel to represent a 48x48 bitmap.  Yuck. */
-  for (i = 0, p = F; i < (PIXELS / 8); ++i)
+  for (i = 0, p = (UChar_Binary *) F; i < (PIXELS / 8); ++i)
     {
       int n, b;
       /* reverse the bit order of each byte... */
@@ -1716,7 +1716,7 @@ mswindows_print_image_instance (Lisp_Image_Instance *p,
 	  write_fmt_string (printcharfun, "/0x%lx",
 			    (unsigned long) IMAGE_INSTANCE_MSWINDOWS_MASK (p));
 	}
-      write_c_string (")", printcharfun);
+      write_c_string (printcharfun, ")");
       break;
 
     default:
@@ -1803,16 +1803,16 @@ static Lisp_Object
 charset_of_text (Lisp_Object text)
 {
 #ifdef MULE
-  Intbyte *p;
+  Ibyte *p;
 
   if (NILP (text))
     return Vcharset_ascii;
   for (p = XSTRING_DATA (text); *p;)
     {
-      Emchar c = charptr_emchar (p);
-      if (!EQ (CHAR_CHARSET (c), Vcharset_ascii))
-	return CHAR_CHARSET (c);
-      INC_CHARPTR (p);
+      Ichar c = itext_ichar (p);
+      if (!EQ (ichar_charset (c), Vcharset_ascii))
+	return ichar_charset (c);
+      INC_IBYTEPTR (p);
     }
 #endif /* MULE */
 
@@ -1852,16 +1852,18 @@ mswindows_widget_hfont (Lisp_Object face,
   return mswindows_get_hfont (XFONT_INSTANCE (font), under, strike);
 }
 
+#ifdef DEFER_WINDOW_POS
+
 static HDWP
 begin_defer_window_pos (struct frame *f)
 {
-#ifdef DEFER_WINDOW_POS
   if (FRAME_MSWINDOWS_DATA (f)->hdwp == 0)
     FRAME_MSWINDOWS_DATA (f)->hdwp = BeginDeferWindowPos (10);
-#endif
   return FRAME_MSWINDOWS_DATA (f)->hdwp;
 }
 
+#endif
+
 /* unmap the image if it is a widget. This is used by redisplay via
    redisplay_unmap_subwindows */
 static void
@@ -1954,6 +1956,16 @@ mswindows_map_subwindow (Lisp_Image_Instance *p, int x, int y,
 		    0, 0, 0, 0,
 		    SWP_NOZORDER | SWP_NOSIZE | SWP_NOMOVE
 		    | SWP_SHOWWINDOW | SWP_NOCOPYBITS | SWP_NOACTIVATE);
+
+      /* Doing this once does not seem to be enough, for instance when
+	 mapping the search dialog this gets called four times. If we
+	 only set on the first time through then the subwindow never
+	 gets focus as intended. However, doing this everytime doesn't
+	 seem so bad, after all we only need to redo this after the
+	 focus changes - and if that happens resetting the initial
+	 focus doesn't seem so bad. */
+      if (IMAGE_INSTANCE_WANTS_INITIAL_FOCUS (p))
+	SetFocus (WIDGET_INSTANCE_MSWINDOWS_HANDLE (p));
 #endif
     }
 }
@@ -2038,6 +2050,13 @@ mswindows_redisplay_widget (Lisp_Image_Instance *p)
 
 #ifdef HAVE_WIDGETS
 
+/* Account for some of the limitations with widget images. */
+static int
+mswindows_widget_border_width (void)
+{
+  return DEFAULT_WIDGET_BORDER_WIDTH;
+}
+
 /* register widgets into our hashtable so that we can cope with the
    callbacks. The hashtable is weak so deregistration is handled
    automatically */
@@ -2196,7 +2215,7 @@ mswindows_widget_instantiate (Lisp_Object image_instance,
 			      Lisp_Object instantiator,
 			      Lisp_Object pointer_fg, Lisp_Object pointer_bg,
 			      int dest_mask, Lisp_Object domain,
-			      const CIntbyte *class, int flags, int exflags)
+			      const CIbyte *class, int flags, int exflags)
 {
   /* this function can call lisp */
   Lisp_Image_Instance *ii = XIMAGE_INSTANCE (image_instance);
@@ -2274,11 +2293,6 @@ mswindows_widget_instantiate (Lisp_Object image_instance,
 		    (IMAGE_INSTANCE_WIDGET_FACE (ii), domain,
 		     IMAGE_INSTANCE_WIDGET_TEXT (ii)),
 		    MAKELPARAM (TRUE, 0));
-#if 0
-  /* #### doesn't work.  need to investigate more closely. */
-  if (IMAGE_INSTANCE_WANTS_INITIAL_FOCUS (ii))
-    SetFocus (wnd);
-#endif
 }
 
 /* Instantiate a native layout widget. */
@@ -2763,7 +2777,7 @@ mswindows_combo_box_instantiate (Lisp_Object image_instance,
   default_face_font_info (domain, 0, 0, &height, 0, 0);
   GET_LIST_LENGTH (items, len);
 
-  height = (height + WIDGET_BORDER_HEIGHT * 2 ) * len;
+  height = (height + DEFAULT_WIDGET_BORDER_WIDTH * 2 ) * len;
   IMAGE_INSTANCE_HEIGHT (ii) = height;
 
   /* Now create the widget. */
@@ -2804,7 +2818,7 @@ mswindows_widget_property (Lisp_Object image_instance, Lisp_Object prop)
   if (EQ (prop, Q_text))
     {
       Charcount tchar_len = qxeSendMessage (wnd, WM_GETTEXTLENGTH, 0, 0);
-      Extbyte *buf = (Extbyte *) alloca (XETCHAR_SIZE * (tchar_len + 1));
+      Extbyte *buf = (Extbyte *) ALLOCA (XETCHAR_SIZE * (tchar_len + 1));
 
       qxeSendMessage (wnd, WM_GETTEXT, (WPARAM)tchar_len + 1, (LPARAM) buf);
       return build_tstr_string (buf);
@@ -2841,7 +2855,7 @@ mswindows_combo_box_property (Lisp_Object image_instance, Lisp_Object prop)
       long item = qxeSendMessage (wnd, CB_GETCURSEL, 0, 0);
       Charcount tchar_len = qxeSendMessage (wnd, CB_GETLBTEXTLEN,
 					    (WPARAM)item, 0);
-      Extbyte *buf = (Extbyte *) alloca (XETCHAR_SIZE * (tchar_len + 1));
+      Extbyte *buf = (Extbyte *) ALLOCA (XETCHAR_SIZE * (tchar_len + 1));
       qxeSendMessage (wnd, CB_GETLBTEXT, (WPARAM)item, (LPARAM) buf);
       return build_tstr_string (buf);
     }
@@ -2941,6 +2955,7 @@ console_type_create_glyphs_mswindows (void)
   CONSOLE_HAS_METHOD (mswindows, locate_pixmap_file);
 #ifdef HAVE_WIDGETS
   CONSOLE_HAS_METHOD (mswindows, widget_query_string_geometry);
+  CONSOLE_HAS_METHOD (mswindows, widget_border_width);
 #endif
 
   /* image methods - printer */
