@@ -549,6 +549,25 @@ gui_item_display_flush_right (Lisp_Object gui_item)
   return Qnil;
 }
 
+#ifdef USE_KKCC
+static const struct lrecord_description gui_item_description [] = {
+  { XD_LISP_OBJECT, offsetof (struct Lisp_Gui_Item, name) },
+  { XD_LISP_OBJECT, offsetof (struct Lisp_Gui_Item, callback) },
+  { XD_LISP_OBJECT, offsetof (struct Lisp_Gui_Item, callback_ex) },
+  { XD_LISP_OBJECT, offsetof (struct Lisp_Gui_Item, suffix) },
+  { XD_LISP_OBJECT, offsetof (struct Lisp_Gui_Item, active) },
+  { XD_LISP_OBJECT, offsetof (struct Lisp_Gui_Item, included) },
+  { XD_LISP_OBJECT, offsetof (struct Lisp_Gui_Item, config) },
+  { XD_LISP_OBJECT, offsetof (struct Lisp_Gui_Item, filter) },
+  { XD_LISP_OBJECT, offsetof (struct Lisp_Gui_Item, style) },
+  { XD_LISP_OBJECT, offsetof (struct Lisp_Gui_Item, selected) },
+  { XD_LISP_OBJECT, offsetof (struct Lisp_Gui_Item, keys) },
+  { XD_LISP_OBJECT, offsetof (struct Lisp_Gui_Item, accelerator) },
+  { XD_LISP_OBJECT, offsetof (struct Lisp_Gui_Item, value) },
+  { XD_END }
+};
+#endif /* USE_KKCC */
+
 static Lisp_Object
 mark_gui_item (Lisp_Object obj)
 {
@@ -770,13 +789,22 @@ finalize_gui_item (void *header, int for_disksave)
 {
 }
 
+#ifdef USE_KKCC
+DEFINE_LRECORD_IMPLEMENTATION ("gui-item", gui_item,
+			       0, /*dumpable-flag*/
+			       mark_gui_item, print_gui_item,
+			       finalize_gui_item, gui_item_equal,
+			       gui_item_hash,
+			       gui_item_description,
+			       Lisp_Gui_Item);
+#else /* not USE_KKCC */
 DEFINE_LRECORD_IMPLEMENTATION ("gui-item", gui_item,
 			       mark_gui_item, print_gui_item,
 			       finalize_gui_item, gui_item_equal,
 			       gui_item_hash,
 			       0,
 			       Lisp_Gui_Item);
-
+#endif /* not USE_KKCC */
 
 DOESNT_RETURN
 gui_error (const Char_ASCII *reason, Lisp_Object frob)
