@@ -42,22 +42,24 @@ Boston, MA 02111-1307, USA.  */
 
 #include <config.h>
 #include "lisp.h"
+
+#include "sysfile.h"
+
 #include "buffer.h"
 #include "bytecode.h"
 #include "casetab.h"
 #include "chartab.h"
-#include "console.h"
-#include "device.h"
+#include "device-impl.h"
 #include "elhash.h"
 #include "events.h"
-#include "extents.h"
+#include "extents-impl.h"
 #include "faces.h"
-#include "frame.h"
+#include "frame-impl.h"
 #include "glyphs.h"
 #include "gui.h"
 #include "keymap.h"
 #include "lstream.h"
-#include "objects.h"
+#include "objects-impl.h"
 #include "opaque.h"
 #include "process.h"
 #include "rangetab.h"
