@@ -217,7 +217,7 @@ file WINBASE.H
 yes GetBinaryType
 yes GetShortPathName
 yes GetLongPathName
-yes GetEnvironmentStrings
+skip GetEnvironmentStrings misnamed ANSI version of the function
 yes FreeEnvironmentStrings
 yes FormatMessage
 yes CreateMailslot
@@ -1925,6 +1925,8 @@ copy_logfontw_to_logfonta (const LOGFONTW *src, LOGFONTA *dst)
   memcpy (dst, src, sizeof (LOGFONTA));
 }
 
+#if 0 /* unused */
+
 static void
 copy_enumlogfonta_to_enumlogfontw (const ENUMLOGFONTA *src, ENUMLOGFONTW *dst)
 {
@@ -1940,6 +1942,8 @@ copy_enumlogfonta_to_enumlogfontw (const ENUMLOGFONTA *src, ENUMLOGFONTW *dst)
   memcpy (dst->elfStyle, src->elfStyle, sizeof (src->elfStyle));
 }
 
+#endif /* 0 */
+
 static void
 copy_enumlogfontexa_to_enumlogfontexw (const ENUMLOGFONTEXA *src,
 				       ENUMLOGFONTEXW *dst)
@@ -1997,6 +2001,8 @@ copy_newtextmetricexa_to_newtextmetricexw (const NEWTEXTMETRICEXA *src,
   dst->ntmFontSig = src->ntmFontSig;
 }
 
+#if 0 /* unused */
+
 static void
 copy_textmetricw_to_textmetrica (const TEXTMETRICW *src,
 				       TEXTMETRICA *dst)
@@ -2014,6 +2020,8 @@ copy_textmetricw_to_textmetrica (const TEXTMETRICW *src,
   dst->tmBreakChar = (BYTE) src->tmBreakChar;
 }
 
+#endif /* 0 */
+
 static void
 copy_textmetrica_to_textmetricw (const TEXTMETRICA *src,
 				       TEXTMETRICW *dst)
