@@ -35,18 +35,37 @@ Boston, MA 02111-1307, USA.  */
 
 #define MAX_READLINKS 32
 
+#if defined (HAVE_SYS_PARAM_H) && !defined (WIN32_NATIVE)
+#include <sys/param.h>
+#endif
+
+#ifdef WIN32_NATIVE
+#include <direct.h>
+#endif
+
+#include <sys/stat.h>			/* for S_IFLNK */
+
+#if defined(WIN32_NATIVE) || defined(CYGWIN)
+#define WIN32_FILENAMES
+#endif
+
 /* First char after start of absolute filename. */
 #define ABS_START(name) (name + ABS_LENGTH (name))
 
 #if defined (WIN32_NATIVE)
 /* Length of start of absolute filename. */
 # define ABS_LENGTH(name) (mswindows_abs_start (name))
-static int mswindows_abs_start (const Intbyte *name);
+static int mswindows_abs_start (const Ibyte *name);
 # define readlink_and_correct_case mswindows_readlink_and_correct_case
 #else
 # ifdef CYGWIN
-#  define ABS_LENGTH(name) (IS_DIRECTORY_SEP (*name) ? \
-                            (IS_DIRECTORY_SEP (name[1]) ? 2 : 1) : 0)
+#  ifdef WIN32_FILENAMES
+#   define ABS_LENGTH(name) (mswindows_abs_start (name))
+static int mswindows_abs_start (const Ibyte * name);
+#  else
+#   define ABS_LENGTH(name) (IS_DIRECTORY_SEP (*name) ? \
+                             (IS_DIRECTORY_SEP (name[1]) ? 2 : 1) : 0)
+#  endif
 #  define readlink_and_correct_case cygwin_readlink_and_correct_case
 # else
 #  define ABS_LENGTH(name) (IS_DIRECTORY_SEP (*name) ? 1 : 0)
@@ -62,14 +81,14 @@ static int mswindows_abs_start (const Intbyte *name);
    are lower-cased. Directories must be given without trailing
    '/'. One day, this could read Win2K's reparse points. */
 static int
-mswindows_readlink_and_correct_case (const Intbyte *name, Intbyte *buf,
+mswindows_readlink_and_correct_case (const Ibyte *name, Ibyte *buf,
 				     int size)
 {
   int len = 0;
   int err = 0;
-  const Intbyte *lastname;
+  const Ibyte *lastname;
   int count = 0;
-  const Intbyte *tmp;
+  const Ibyte *tmp;
   DECLARE_EISTRING (result);
   
   assert (*name);
@@ -136,7 +155,7 @@ mswindows_readlink_and_correct_case (const Intbyte *name, Intbyte *buf,
 #ifdef CYGWIN
 /* Call readlink and try to find out the correct case for the file. */
 static int
-cygwin_readlink_and_correct_case (const Intbyte *name, Intbyte *buf,
+cygwin_readlink_and_correct_case (const Ibyte *name, Ibyte *buf,
 				  int size)
 {
   int n = qxe_readlink (name, buf, size);
@@ -144,8 +163,8 @@ cygwin_readlink_and_correct_case (const Intbyte *name, Intbyte *buf,
     {
       /* The file may exist, but isn't a symlink. Try to find the
          right name. */
-      Intbyte *tmp =
-	(Intbyte *) alloca (cygwin_posix_to_win32_path_list_buf_size
+      Ibyte *tmp =
+	(Ibyte *) ALLOCA (cygwin_posix_to_win32_path_list_buf_size
 			    ((char *) name));
       cygwin_posix_to_win32_path_list ((char *) name, (char *) tmp);
       n = mswindows_readlink_and_correct_case (tmp, buf, size);
@@ -154,13 +173,13 @@ cygwin_readlink_and_correct_case (const Intbyte *name, Intbyte *buf,
 }
 #endif /* CYGWIN */
 
-#ifdef WIN32_NATIVE
+#ifdef WIN32_FILENAMES
 #ifndef ELOOP
 #define ELOOP 10062 /* = WSAELOOP in winsock.h */
 #endif
 /* Length of start of absolute filename. */
 static int 
-mswindows_abs_start (const Intbyte *name)
+mswindows_abs_start (const Ibyte *name)
 {
   if (isalpha (*name) && IS_DEVICE_SEP (name[1])
       && IS_DIRECTORY_SEP (name[2]))
@@ -175,15 +194,15 @@ mswindows_abs_start (const Intbyte *name)
 /* Mule Note: This function works with and returns
    internally-formatted strings. */
 
-Intbyte *
-qxe_realpath (const Intbyte *path, Intbyte *resolved_path)
+Ibyte *
+qxe_realpath (const Ibyte *path, Ibyte *resolved_path)
 {
-  Intbyte copy_path[PATH_MAX];
-  Intbyte *new_path = resolved_path;
-  Intbyte *max_path;
+  Ibyte copy_path[PATH_MAX];
+  Ibyte *new_path = resolved_path;
+  Ibyte *max_path;
 #if defined (HAVE_READLINK) || defined (WIN32_NATIVE)
   int readlinks = 0;
-  Intbyte link_path[PATH_MAX];
+  Ibyte link_path[PATH_MAX];
   int n;
   int abslen = ABS_LENGTH (path);
 #endif
@@ -193,9 +212,11 @@ qxe_realpath (const Intbyte *path, Intbyte *resolved_path)
   path = copy_path;
   max_path = copy_path + PATH_MAX - 2;
 
-#ifdef WIN32_NATIVE
+  if (0)
+    ;
+#ifdef WIN32_FILENAMES
   /* Check for c:/... or //server/... */
-  if (abslen == 2 || abslen == 3)
+  else if (abslen == 2 || abslen == 3)
     {
       qxestrncpy (new_path, path, abslen);
       /* Make sure drive letter is lowercased. */
@@ -204,6 +225,8 @@ qxe_realpath (const Intbyte *path, Intbyte *resolved_path)
       new_path += abslen;
       path += abslen;
     }
+#endif
+#ifdef WIN32_NATIVE
   /* No drive letter, but a beginning slash? Prepend drive letter. */
   else if (abslen == 1)
     {
@@ -212,7 +235,7 @@ qxe_realpath (const Intbyte *path, Intbyte *resolved_path)
       path++;
     }
   /* Just a path name, prepend the current directory */
-  else
+  else if (1)
     {
       get_initial_directory (new_path, PATH_MAX - 1);
       new_path += qxestrlen (new_path);
@@ -221,7 +244,7 @@ qxe_realpath (const Intbyte *path, Intbyte *resolved_path)
     }
 #else
   /* If it's a relative pathname use get_initial_directory for starters. */
-  if (abslen == 0)
+  else if (abslen == 0)
     {
       get_initial_directory (new_path, PATH_MAX - 1);
       new_path += qxestrlen (new_path);
