@@ -2,6 +2,7 @@
    Copyright (C) 1994, 1995 Board of Trustees, University of Illinois.
    Copyright (C) 1994 Lucid, Inc.
    Copyright (C) 1995 Sun Microsystems, Inc.
+   Copyright (C) 2002 Ben Wing.
 
 This file is part of XEmacs.
 
@@ -30,25 +31,26 @@ Boston, MA 02111-1307, USA.  */
 #include <config.h>
 #include "lisp.h"
 
-#include "console-gtk.h"
-#include "gccache-gtk.h"
-#include "glyphs-gtk.h"
-#include "objects-gtk.h"
-
 #include "buffer.h"
 #include "debug.h"
+#include "device-impl.h"
 #include "faces.h"
-#include "frame.h"
+#include "file-coding.h"
+#include "frame-impl.h"
 #include "gutter.h"
 #include "redisplay.h"
 #include "sysdep.h"
 #include "window.h"
 
+#include "console-gtk-impl.h"
+#include "gccache-gtk.h"
+#include "glyphs-gtk.h"
+#include "objects-gtk-impl.h"
+
 #include "sysproc.h" /* for select() */
 
 #ifdef MULE
 #include "mule-ccl.h"
-#include "file-coding.h" /* for CCL conversion */
 #endif
 
 #define CONST const
@@ -103,7 +105,7 @@ struct textual_run
    al.  (This means converting to one or two byte format, possibly
    tweaking the high bits, and possibly running a CCL program.) You
    must pre-allocate the space used and pass it in. (This is done so
-   you can alloca() the space.)  You need to allocate (2 * len) bytes
+   you can ALLOCA () the space.)  You need to allocate (2 * len) bytes
    of TEXT_STORAGE and (len * sizeof (struct textual_run)) bytes of
    RUN_STORAGE, where LEN is the length of the dynarr.
 
@@ -112,7 +114,7 @@ struct textual_run
 static int
 separate_textual_runs (unsigned char *text_storage,
 		       struct textual_run *run_storage,
-		       CONST Emchar *str, Charcount len)
+		       CONST Ichar *str, Charcount len)
 {
   Lisp_Object prev_charset = Qunbound; /* not Qnil because that is a
 					  possible valid charset when
@@ -126,13 +128,13 @@ separate_textual_runs (unsigned char *text_storage,
 
   for (i = 0; i < len; i++)
     {
-      Emchar ch = str[i];
+      Ichar ch = str[i];
       Lisp_Object charset;
       int byte1, byte2;
       int dimension;
       int graphic;
 
-      BREAKUP_CHAR (ch, charset, byte1, byte2);
+      BREAKUP_ICHAR (ch, charset, byte1, byte2);
       dimension = XCHARSET_DIMENSION (charset);
       graphic   = XCHARSET_GRAPHIC   (charset);
 
@@ -238,11 +240,11 @@ gtk_text_width_single_run (struct face_cachel *cachel, struct textual_run *run)
    */
 
 static int
-gtk_text_width (struct frame *f, struct face_cachel *cachel, CONST Emchar *str,
+gtk_text_width (struct frame *f, struct face_cachel *cachel, CONST Ichar *str,
 		Charcount len)
 {
   int width_so_far = 0;
-  unsigned char *text_storage = (unsigned char *) alloca (2 * len);
+  unsigned char *text_storage = (unsigned char *) ALLOCA (2 * len);
   struct textual_run *runs = alloca_array (struct textual_run, len);
   int nruns;
   int i;
@@ -294,7 +296,7 @@ gtk_output_display_block (struct window *w, struct display_line *dl, int block,
 			  int cursor_width, int cursor_height)
 {
   struct frame *f = XFRAME (w->frame);
-  Emchar_dynarr *buf = Dynarr_new (Emchar);
+  Ichar_dynarr *buf = Dynarr_new (Ichar);
   Lisp_Object window;
 
   struct display_block *db = Dynarr_atp (dl->display_blocks, block);
@@ -321,7 +323,7 @@ gtk_output_display_block (struct window *w, struct display_line *dl, int block,
       xpos = rb->xpos;
       width = 0;
       if (rb->type == RUNE_CHAR)
-	charset = CHAR_CHARSET (rb->object.chr.ch);
+	charset = ichar_charset (rb->object.chr.ch);
     }
 
   if (end < 0)
@@ -334,7 +336,7 @@ gtk_output_display_block (struct window *w, struct display_line *dl, int block,
 
       if (rb->findex == findex && rb->type == RUNE_CHAR
 	  && rb->object.chr.ch != '\n' && rb->cursor_type != CURSOR_ON
-	  && EQ (charset, CHAR_CHARSET (rb->object.chr.ch)))
+	  && EQ (charset, ichar_charset (rb->object.chr.ch)))
 	{
 	  Dynarr_add (buf, rb->object.chr.ch);
 	  width += rb->width;
@@ -357,7 +359,7 @@ gtk_output_display_block (struct window *w, struct display_line *dl, int block,
 	    {
 	      findex = rb->findex;
 	      xpos = rb->xpos;
-	      charset = CHAR_CHARSET (rb->object.chr.ch);
+	      charset = ichar_charset (rb->object.chr.ch);
 
 	      if (rb->cursor_type == CURSOR_ON)
 		{
@@ -421,8 +423,8 @@ gtk_output_display_block (struct window *w, struct display_line *dl, int block,
 	      struct display_box dbox;
 	      struct display_glyph_area dga;
 	      redisplay_calculate_display_boxes (dl, rb->xpos, rb->object.dglyph.xoffset,
-						 start_pixpos, rb->width,
-						 &dbox, &dga);
+						 rb->object.dglyph.yoffset ,start_pixpos,
+                                                 rb->width, &dbox, &dga);
 
 	      window = wrap_window (w);
 	      instance = glyph_image_instance (rb->object.dglyph.glyph,
@@ -438,7 +440,7 @@ gtk_output_display_block (struct window *w, struct display_line *dl, int block,
 			 add_glyph_rune(). */
 		      Lisp_Object string =
 			XIMAGE_INSTANCE_TEXT_STRING (instance);
-		      convert_intbyte_string_into_emchar_dynarr
+		      convert_ibyte_string_into_ichar_dynarr
 			(XSTRING_DATA (string), XSTRING_LENGTH (string), buf);
 
 		      gtk_output_string (w, dl, buf, xpos,
@@ -626,7 +628,7 @@ gtk_get_gc (struct device *d, Lisp_Object font, Lisp_Object fg, Lisp_Object bg,
  DL		Display line that this text is on.  The values in the
  		structure are used to determine the vertical position and
 		clipping range of the text.
- BUF		Dynamic array of Emchars specifying what is actually to be
+ BUF		Dynamic array of Ichars specifying what is actually to be
 		drawn.
  XPOS		X position in pixels where the text should start being drawn.
  XOFFSET	Number of pixels to be chopped off the left side of the
@@ -657,7 +659,7 @@ void gdk_draw_text_image (GdkDrawable *drawable,
 
 void
 gtk_output_string (struct window *w, struct display_line *dl,
-		   Emchar_dynarr *buf, int xpos, int xoffset, int clip_start,
+		   Ichar_dynarr *buf, int xpos, int xoffset, int clip_start,
 		   int width, face_index findex, int cursor,
 		   int cursor_start, int cursor_width, int cursor_height)
 {
@@ -682,7 +684,7 @@ gtk_output_string (struct window *w, struct display_line *dl,
   GdkGC *bgc, *gc;
   int height;
   int len = Dynarr_length (buf);
-  unsigned char *text_storage = (unsigned char *) alloca (2 * len);
+  unsigned char *text_storage = (unsigned char *) ALLOCA (2 * len);
   struct textual_run *runs = alloca_array (struct textual_run, len);
   int nruns;
   int i;
