@@ -211,7 +211,7 @@ typedef int ssize_t;
 #define MAIL_USE_LOCKING
 
 /* See unexnt.c */
-#if (_MSC_VER >= 1100)
+#if (_MSC_VER >= 1100) && !defined(PDUMP)
 #define DUMP_SEPARATE_SECTION
 #endif
 #ifdef DUMP_SEPARATE_SECTION
@@ -219,29 +219,39 @@ typedef int ssize_t;
 #pragma bss_seg("xdata")
 #endif
 
-#ifdef HAVE_SCROLLBARS
-/* Ensure the NT 4 mouse definitions in winuser.h are available */
+#ifdef emacs
+/* intl-auto-encap-win32.[ch] assumes _WIN32_WINNT>=0x0400
+   We don't want this set when building command-line helpers in lib-src */
 # ifndef _WIN32_WINNT
 #  define _WIN32_WINNT 0x0400
 # endif
 #endif
 
-/* Force the various NT 4 structures and constants to be included; we're
-   careful not to call (or even link with) functions not in NT 3.51 when
-   running on 3.51, but when running on NT 4 or Win9x, we use the later
-   functions, and need their headers. */
 /* The VC++ (5.0, at least) headers treat WINVER non-existent as 0x0400 */
 #if defined (WINVER) && WINVER < 0x0400
 # undef WINVER
 # define WINVER 0x0400
 #endif
 
+/* Vararg routines, main(), and callback routines for library functions
+   (qsort(), signal(), etc.) need to be __cdecl if we use the fastcall
+   convention by default (a good idea, since it speeds things up). #### Why
+   do they have to complain about this?  Why not just do the right thing
+   automatically?
+
+   Prefix with X because plain CDECL is already defined by the VC++ header
+   files. */
+#define XCDECL __cdecl
+
 /* MSVC 6.0 has a mechanism to declare functions which never return */
 #if (_MSC_VER >= 1200)
 #define DOESNT_RETURN __declspec(noreturn) void
 #define DECLARE_DOESNT_RETURN(decl) __declspec(noreturn) extern void decl
 #define DECLARE_DOESNT_RETURN_GCC_ATTRIBUTE_SYNTAX_SUCKS(decl,str,idx) \
-          __declspec(noreturn) extern void decl PRINTF_ARGS(str,idx)
+          __declspec(noreturn) extern void __cdecl decl PRINTF_ARGS(str,idx)
+#else
+#define DECLARE_DOESNT_RETURN_GCC_ATTRIBUTE_SYNTAX_SUCKS(decl,str,idx) \
+          extern void __cdecl decl PRINTF_ARGS(str,idx)
 #endif /* MSVC 6.0 */
 
 /* MSVC warnings no-no crap. When adding one to this section,
