@@ -27,14 +27,14 @@ Boston, MA 02111-1307, USA.  */
 #include <config.h>
 #include "lisp.h"
 
-#include "console-gtk.h"
+#include "frame-impl.h"
+#include "window.h"
+
+#include "console-gtk-impl.h"
 #include "glyphs-gtk.h"
 #include "gui-gtk.h"
 #include "scrollbar-gtk.h"
 
-#include "frame.h"
-#include "window.h"
-
 static gboolean scrollbar_cb (GtkAdjustment *adj, gpointer user_data);
 
 /* Used to prevent changing the size of the slider while drag
