@@ -33,13 +33,13 @@ Boston, MA 02111-1307, USA.  */
 #include "device.h"
 #include "elhash.h"
 #include "events.h"
-#include "frame.h"
+#include "frame-impl.h"
 #include "opaque.h"
 #include "scrollbar.h"
 #include "specifier.h"
-#include "window.h"
+#include "window-impl.h"
 
-#include "console-msw.h"
+#include "console-msw-impl.h"
 #include "scrollbar-msw.h"
 
 /* We use a similar sort of vertical scrollbar drag hack for mswindows
@@ -94,7 +94,7 @@ mswindows_free_scrollbar_instance (struct scrollbar_instance *sb)
     (void *) qxeGetWindowLong (SCROLLBAR_MSW_HANDLE (sb), GWL_USERDATA);
   Lisp_Object ptr;
 
-  VOID_TO_LISP (ptr, opaque);
+  ptr = VOID_TO_LISP (opaque);
   assert (OPAQUE_PTRP (ptr));
   ptr = Fremhash (ptr, Vmswindows_scrollbar_instance_table);
   assert (!NILP (ptr));
@@ -221,7 +221,7 @@ mswindows_handle_scrollbar_event (HWND hwnd, int code, int pos)
   else
     {
       Lisp_Object ptr;
-      VOID_TO_LISP (ptr, v);
+      ptr = VOID_TO_LISP (v);
       assert (OPAQUE_PTRP (ptr));
       ptr = Fgethash (ptr, Vmswindows_scrollbar_instance_table, Qnil);
       sb = XSCROLLBAR_INSTANCE (ptr);
@@ -335,7 +335,7 @@ mswindows_handle_mousewheel_event (Lisp_Object frame, int keys, int delta,
 {
   int hasVertBar, hasHorzBar;	/* Indicates presence of scroll bars */
   unsigned wheelScrollLines = 0; /* Number of lines per wheel notch */
-  Lisp_Object win, corpore, sano;
+  Lisp_Object win = Qnil, corpore, sano;
   struct window_mirror *mirror;
   int mene, _mene, tekel, upharsin;
   Charbpos mens, sana;
@@ -352,19 +352,22 @@ mswindows_handle_mousewheel_event (Lisp_Object frame, int keys, int delta,
      frame. */
   if (ScreenToClient (FRAME_MSWINDOWS_HANDLE (XFRAME (frame)), 
 		      &donde_esta) != 0)
-    /* stderr_out ("donde_esta: %d %d\n", donde_esta.x, donde_esta.y); */
-    pixel_to_glyph_translation (XFRAME (frame), donde_esta.x, donde_esta.y,
-				&mene, &_mene, &tekel, &upharsin,
-				&needle_in_haystack,
-				&mens, &sana, &in, &corpore, &sano);
-
-  if (needle_in_haystack)
     {
-      win = wrap_window (needle_in_haystack);
-      /* stderr_out ("found needle\n");
-	 debug_print (win); */
+      /* stderr_out ("donde_esta: %d %d\n", donde_esta.x, donde_esta.y); */
+      pixel_to_glyph_translation (XFRAME (frame), donde_esta.x, donde_esta.y,
+				  &mene, &_mene, &tekel, &upharsin,
+				  &needle_in_haystack,
+				  &mens, &sana, &in, &corpore, &sano);
+      
+      if (needle_in_haystack)
+	{
+	  win = wrap_window (needle_in_haystack);
+	  /* stderr_out ("found needle\n");
+	     debug_print (win); */
+	}
     }
-  else
+  
+  if (!needle_in_haystack)
     {
       win = FRAME_SELECTED_WINDOW (XFRAME (frame));
       needle_in_haystack = XWINDOW (win);
@@ -489,11 +492,7 @@ void
 vars_of_scrollbar_mswindows (void)
 {
   Fprovide (intern ("mswindows-scrollbars"));
-}
 
-void
-complex_vars_of_scrollbar_mswindows (void)
-{
   staticpro (&Vmswindows_scrollbar_instance_table);
   Vmswindows_scrollbar_instance_table =
     make_lisp_hash_table (100, HASH_TABLE_NON_WEAK, HASH_TABLE_EQ);
