@@ -56,6 +56,22 @@ Lisp_Object Q_size;
 
 Lisp_Object Qinit_toolbar_from_resources;
 
+#ifdef USE_KKCC
+static const struct lrecord_description toolbar_button_description [] = {
+  { XD_LISP_OBJECT, offsetof (struct toolbar_button, next) },
+  { XD_LISP_OBJECT, offsetof (struct toolbar_button, frame) },
+  { XD_LISP_OBJECT, offsetof (struct toolbar_button, up_glyph) },
+  { XD_LISP_OBJECT, offsetof (struct toolbar_button, down_glyph) },
+  { XD_LISP_OBJECT, offsetof (struct toolbar_button, disabled_glyph) },
+  { XD_LISP_OBJECT, offsetof (struct toolbar_button, cap_up_glyph) },
+  { XD_LISP_OBJECT, offsetof (struct toolbar_button, cap_down_glyph) },
+  { XD_LISP_OBJECT, offsetof (struct toolbar_button, cap_disabled_glyph) },
+  { XD_LISP_OBJECT, offsetof (struct toolbar_button, callback) },
+  { XD_LISP_OBJECT, offsetof (struct toolbar_button, enabled_p) },
+  { XD_LISP_OBJECT, offsetof (struct toolbar_button, help_string) },
+  { XD_END }
+};
+#endif /* USE_KKCC */
 
 static Lisp_Object
 mark_toolbar_button (Lisp_Object obj)
@@ -74,9 +90,17 @@ mark_toolbar_button (Lisp_Object obj)
   return data->help_string;
 }
 
+#ifdef USE_KKCC
+DEFINE_LRECORD_IMPLEMENTATION ("toolbar-button", toolbar_button,
+			       0, /*dumpable-flag*/
+			       mark_toolbar_button, 0, 0, 0, 0, 
+			       toolbar_button_description,
+			       struct toolbar_button);
+#else /* not USE_KKCC */
 DEFINE_LRECORD_IMPLEMENTATION ("toolbar-button", toolbar_button,
 			       mark_toolbar_button, 0, 0, 0, 0, 0,
 			       struct toolbar_button);
+#endif /* not USE_KKCC */
 
 DEFUN ("toolbar-button-p", Ftoolbar_button_p, 1, 1, 0, /*
 Return non-nil if OBJECT is a toolbar button.
