@@ -2,8 +2,9 @@
 emacs_is_beta=t
 emacs_major_version=21
 emacs_minor_version=5
-emacs_beta_version=8
-xemacs_codename="broccoli"
+emacs_beta_version=9
+xemacs_codename="brussels sprouts"
+xemacs_extra_name=
 emacs_kit_version=
 infodock_major_version=4
 infodock_minor_version=0
